@@ -1,4 +1,4 @@
-# Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2011-2015, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,25 +10,25 @@ package Devel::Cover::DB::IO;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.21'; # VERSION
 
 my $Format;
 
-BEGIN
-{
-    $Format = "JSON"     if              eval "use JSON; 1";
+BEGIN {
+    $Format = "Sereal"   if eval "use Sereal::Decoder; use Sereal::Encoder; 1";
+    $Format = "JSON"     if !$Format and eval "use JSON; 1";
     $Format = "JSON"     if !$Format and eval "use JSON::PP; 1";
     $Format = "Storable" if !$Format and eval "use Storable; 1";
     die "Can't load either JSON or Storable" unless $Format;
 }
 
-sub new
-{
+sub new {
     my $class = shift;
 
     my $format = $ENV{DEVEL_COVER_DB_FORMAT} || $Format;
+    ($format) = $format =~ /(.*)/;  # die tainting
     die "Devel::Cover: Unrecognised DB format: $format"
-        unless $format =~ /^(?:Storable|JSON)$/;
+        unless $format =~ /^(?:Storable|JSON|Sereal)$/;
 
     $class .= "::$format";
     eval "use $class; 1" or die "Devel::Cover: $@";
@@ -46,7 +46,7 @@ Devel::Cover::DB::IO - IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.08
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2011-2013, Paul Johnson (paul@pjcj.net)
+Copyright 2011-2015, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
