@@ -1,4 +1,4 @@
-# Copyright 2007-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2007-2015, Paul Johnson (paul@pjcj.net)
 # except where otherwise noted.
 
 # This software is free.  It is licensed under the same terms as Perl itself,
@@ -12,7 +12,7 @@ package Devel::Cover::Web;
 use strict;
 use warnings;
 
-our $VERSION = '1.08'; # VERSION
+our $VERSION = '1.21'; # VERSION
 
 use Exporter;
 
@@ -21,12 +21,10 @@ our @EXPORT_OK = "write_file";
 
 my %Files;
 
-sub write_file
-{
+sub write_file {
     my ($directory, $file) = @_;
 
-    while (my($f, $contents) = each %Files)
-    {
+    while (my ($f, $contents) = each %Files) {
         next if
             $file ne "all" &&
             (($file eq "js" || $file eq "css") && $f !~ /\.$file$/) &&
@@ -81,23 +79,16 @@ th,.h,.hh,.sh,.sv {
     background-color   : #cccccc;
     border             : solid 1px #333333;
     padding            : 0em 0.2em;
-    width              : 2.5em;
     -moz-border-radius : 4px;
 }
 
-.hh {
-    width: 25%;
-}
-
 .sh {
-    width       : 0;
     color       : #CD5555;
     font-weight : bold;
     padding     : 0.2em;
 }
 
 .sv {
-    width       : 0;
     padding     : 0.2em;
 }
 
@@ -906,7 +897,7 @@ Devel::Cover::Web - Files for JavaScript or CSS
 
 =head1 VERSION
 
-version 1.08
+version 1.21
 
 =head1 SYNOPSIS
 
@@ -939,7 +930,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2007-2013, Paul Johnson (paul@pjcj.net) except where otherwise noted.
+Copyright 2007-2015, Paul Johnson (paul@pjcj.net) except where otherwise noted.
 
 This software is free.  It is licensed under the same terms as Perl itself,
 except where otherwise noted.
