@@ -1,4 +1,4 @@
-# Copyright 2002-2011, Paul Johnson (pjcj@cpan.org)
+# Copyright 2002-2015, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -7,8 +7,7 @@
 
 package Module_import;
 
-sub import
-{
+sub import {
     print "Module_import\n";
 }
 
