@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2002-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2015, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,8 +10,7 @@
 use strict;
 use warnings;
 
-sub cond_dor
-{
+sub cond_dor {
     my ($x) = @_;
 
     $x->[18] //= undef;
